==> ejc-sddjsorg-api-3.0.0-20211018.072306-27-sources.jar: com/ejianc/business/production/vo/ReformNewShareholderVO.java <==
package com.ejianc.business.production.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 产权登记-改制新股东
 * 
 * @author generator
 * 
 */
public class ReformNewShareholderVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.String captailName; // 出资方名称
    private java.lang.String unicode; // 统一社会信用代码
    private java.lang.Integer beActualContributor; // 是否为国有实际出资人
    private java.lang.String superviseOrg; // 归属监管机构
    

    /**
     * 出资方名称
     */
    public java.lang.String getCaptailName() {
        return captailName;
    }

    /**
     * 出资方名称
     */
    public void setCaptailName(java.lang.String captailName) {
        this.captailName = captailName;
    }
    /**
     * 统一社会信用代码
     */
    public java.lang.String getUnicode() {
        return unicode;
    }

    /**
     * 统一社会信用代码
     */
    public void setUnicode(java.lang.String unicode) {
        this.unicode = unicode;
    }
    /**
     * 是否为国有实际出资人
     */
    public java.lang.Integer getBeActualContributor() {
        return beActualContributor;
    }

    /**
     * 是否为国有实际出资人
     */
    public void setBeActualContributor(java.lang.Integer beActualContributor) {
        this.beActualContributor = beActualContributor;
    }
    /**
     * 归属监管机构
     */
    public java.lang.String getSuperviseOrg() {
        return superviseOrg;
    }

    /**
     * 归属监管机构
     */
    public void setSuperviseOrg(java.lang.String superviseOrg) {
        this.superviseOrg = superviseOrg;
    }
    
}

==> ejc-sddjsorg-api-3.0.0-20211027.120225-109-sources.jar: com/ejianc/business/production/vo/ReformNewShareholderVO.java <==
package com.ejianc.business.production.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 产权登记-改制新股东
 * 
 * @author generator
 * 
 */
public class ReformNewShareholderVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.String captailName; // 出资方名称
    private java.lang.String unicode; // 统一社会信用代码
    private java.lang.Boolean beActualContributor; // 是否为国有实际出资人
    private java.lang.String superviseOrg; // 归属监管机构
    

    /**
     * 出资方名称
     */
    public java.lang.String getCaptailName() {
        return captailName;
    }

    /**
     * 出资方名称
     */
    public void setCaptailName(java.lang.String captailName) {
        this.captailName = captailName;
    }
    /**
     * 统一社会信用代码
     */
    public java.lang.String getUnicode() {
        return unicode;
    }

    /**
     * 统一社会信用代码
     */
    public void setUnicode(java.lang.String unicode) {
        this.unicode = unicode;
    }
    /**
     * 是否为国有实际出资人
     */
    public Boolean getBeActualContributor() {
        return beActualContributor;
    }

    public void setBeActualContributor(Boolean beActualContributor) {
        this.beActualContributor = beActualContributor;
    }

    /**
     * 归属监管机构
     */
    public java.lang.String getSuperviseOrg() {
        return superviseOrg;
    }

    /**
     * 归属监管机构
     */
    public void setSuperviseOrg(java.lang.String superviseOrg) {
        this.superviseOrg = superviseOrg;
    }
    
}
